@@ -22,16 +22,20 @@ from .Group import Group
 from .Header import Header
 from .Image import Image
 from .InputWrapper import InputWrapper
+from .JsonInput import JsonInput
+from .Loader import Loader
 from .MantineProvider import MantineProvider
 from .Modal import Modal
 from .MultiSelect import MultiSelect
 from .Navbar import Navbar
 from .Notification import Notification
 from .NotificationsProvider import NotificationsProvider
+from .NumberInput import NumberInput
 from .Paper import Paper
 from .Prism import Prism
 from .Progress import Progress
 from .RadioGroup import RadioGroup
+from .RingProgress import RingProgress
 from .ScrollArea import ScrollArea
 from .SegmentedControl import SegmentedControl
 from .Select import Select
@@ -46,6 +50,8 @@ from .Table import Table
 from .Tabs import Tabs
 from .Text import Text
 from .TextInput import TextInput
+from .ThemeIcon import ThemeIcon
+from .TimeInput import TimeInput
 from .Title import Title
 from .Tooltip import Tooltip
 
@@ -74,16 +80,20 @@ __all__ = [
     "Header",
     "Image",
     "InputWrapper",
+    "JsonInput",
+    "Loader",
     "MantineProvider",
     "Modal",
     "MultiSelect",
     "Navbar",
     "Notification",
     "NotificationsProvider",
+    "NumberInput",
     "Paper",
     "Prism",
     "Progress",
     "RadioGroup",
+    "RingProgress",
     "ScrollArea",
     "SegmentedControl",
     "Select",
@@ -98,6 +108,8 @@ __all__ = [
     "Tabs",
     "Text",
     "TextInput",
+    "ThemeIcon",
+    "TimeInput",
     "Title",
     "Tooltip"
 ]
\ No newline at end of file
